@@ -45,8 +45,7 @@ from RPA.Assistant.utils import (
 
 @library(scope="GLOBAL", doc_format="REST", auto_keywords=False)
 class Assistant:
-    """This library is still in Beta and needs more testing and features.
-    The `Assistant` library provides a way to display information to a user
+    """The `Assistant` library provides a way to display information to a user
     and request input while a robot is running. It allows building processes
     that require human interaction. Also it offers capabilities of running
     other robots inside the current one and determine what to display to the
@@ -189,10 +188,11 @@ class Assistant:
 
         return ElevatedButton(label, on_click=validate_and_close)
 
-    @keyword("Clear elements")
+    @keyword("Clear dialog")
     def clear_dialog(self) -> None:
         """Remove all previously defined elements and start from a clean state.
         By default this is done automatically when a dialog is created.
+        It will also clear all the results.
 
         Example:
 
@@ -203,7 +203,7 @@ class Assistant:
                 Run dialog    clear=False
                 Process page
             END
-            Clear elements
+            Clear dialog
         """
         self._client.results = {}
         self._client.clear_elements()
@@ -629,7 +629,7 @@ class Assistant:
         .. code-block:: robotframework
 
             # This can be any one file
-            Add file input    name=anyting
+            Add file input    name=anything
 
             # This can be multiple files
             Add file input    name=multiple  multiple=True
